@@ -795,7 +795,7 @@ f"> */
 /* >       University of Kansas, USA */
 /* > */
 /*  ===================================================================== */
-/* Subroutine */ int dlaqr2_(logical *wantt, logical *wantz, integer *n, 
+/* Subroutine */ void dlaqr2_(logical *wantt, logical *wantz, integer *n, 
 	integer *ktop, integer *kbot, integer *nw, doublereal *h__, integer *
 	ldh, integer *iloz, integer *ihiz, doublereal *z__, integer *ldz, 
 	integer *ns, integer *nd, doublereal *sr, doublereal *si, doublereal *
@@ -811,35 +811,35 @@ f"> */
     doublereal beta;
     integer kend, kcol, info, ifst, ilst, ltop, krow, i__, j, k;
     doublereal s;
-    extern /* Subroutine */ int dlarf_(char *, integer *, integer *, 
+    extern /* Subroutine */ void dlarf_(char *, integer *, integer *, 
 	    doublereal *, integer *, doublereal *, doublereal *, integer *, 
 	    doublereal *), dgemm_(char *, char *, integer *, integer *
 	    , integer *, doublereal *, doublereal *, integer *, doublereal *, 
 	    integer *, doublereal *, doublereal *, integer *);
     logical bulge;
-    extern /* Subroutine */ int dcopy_(integer *, doublereal *, integer *, 
+    extern /* Subroutine */ void dcopy_(integer *, doublereal *, integer *, 
 	    doublereal *, integer *);
     integer infqr, kwtop;
-    extern /* Subroutine */ int dlanv2_(doublereal *, doublereal *, 
+    extern /* Subroutine */ void dlanv2_(doublereal *, doublereal *, 
 	    doublereal *, doublereal *, doublereal *, doublereal *, 
 	    doublereal *, doublereal *, doublereal *, doublereal *);
     doublereal aa, bb, cc;
-    extern /* Subroutine */ int dlabad_(doublereal *, doublereal *);
+    extern /* Subroutine */ void dlabad_(doublereal *, doublereal *);
     doublereal dd, cs;
     extern doublereal dlamch_(char *);
-    extern /* Subroutine */ int dgehrd_(integer *, integer *, integer *, 
+    extern /* Subroutine */ void dgehrd_(integer *, integer *, integer *, 
 	    doublereal *, integer *, doublereal *, doublereal *, integer *, 
 	    integer *), dlarfg_(integer *, doublereal *, doublereal *, 
 	    integer *, doublereal *);
     doublereal sn;
     integer jw;
-    extern /* Subroutine */ int dlahqr_(logical *, logical *, integer *, 
+    extern /* Subroutine */ void dlahqr_(logical *, logical *, integer *, 
 	    integer *, integer *, doublereal *, integer *, doublereal *, 
 	    doublereal *, integer *, integer *, doublereal *, integer *, 
 	    integer *), dlacpy_(char *, integer *, integer *, doublereal *, 
 	    integer *, doublereal *, integer *);
     doublereal safmin, safmax;
-    extern /* Subroutine */ int dlaset_(char *, integer *, integer *, 
+    extern /* Subroutine */ void dlaset_(char *, integer *, integer *, 
 	    doublereal *, doublereal *, doublereal *, integer *), 
 	    dtrexc_(char *, integer *, doublereal *, integer *, doublereal *, 
 	    integer *, integer *, integer *, doublereal *, integer *),
@@ -916,7 +916,7 @@ f"> */
 
     if (*lwork == -1) {
 	work[1] = (doublereal) lwkopt;
-	return 0;
+	return;
     }
 
 /*     ==== Nothing to do ... */
@@ -925,11 +925,11 @@ f"> */
     *nd = 0;
     work[1] = 1.;
     if (*ktop > *kbot) {
-	return 0;
+	return;
     }
 /*     ... nor for an empty deflation window. ==== */
     if (*nw < 1) {
-	return 0;
+	return;
     }
 
 /*     ==== Machine constants ==== */
@@ -971,7 +971,7 @@ f"> */
 	    }
 	}
 	work[1] = 1.;
-	return 0;
+	return;
     }
 
 /*     ==== Convert to spike-triangular form.  (In case of a */
@@ -1312,6 +1312,6 @@ L60:
 
 /*     ==== End of DLAQR2 ==== */
 
-    return 0;
+    return;
 } /* dlaqr2_ */
 
