@@ -699,7 +699,7 @@ f"> */
 /* >  Modified description of INFO. Sven, 16 Feb 05. \n */
 /* > */
 /*  ===================================================================== */
-/* Subroutine */ int dsyevd_(char *jobz, char *uplo, integer *n, doublereal *
+/* Subroutine */ void dsyevd_(char *jobz, char *uplo, integer *n, doublereal *
 	a, integer *lda, doublereal *w, doublereal *work, integer *lwork, 
 	integer *iwork, integer *liwork, integer *info)
 {
@@ -711,7 +711,7 @@ f"> */
     integer inde;
     doublereal anrm, rmin, rmax;
     integer lopt;
-    extern /* Subroutine */ int dscal_(integer *, doublereal *, doublereal *, 
+    extern /* Subroutine */ void dscal_(integer *, doublereal *, doublereal *, 
 	    integer *);
     doublereal sigma;
     extern logical lsame_(char *, char *);
@@ -720,7 +720,7 @@ f"> */
     integer indwk2, llwrk2;
     extern doublereal dlamch_(char *);
     integer iscale;
-    extern /* Subroutine */ int dlascl_(char *, integer *, integer *, 
+    extern /* Subroutine */ void dlascl_(char *, integer *, integer *, 
 	    doublereal *, doublereal *, integer *, integer *, doublereal *, 
 	    integer *, integer *), dstedc_(char *, integer *, 
 	    doublereal *, doublereal *, doublereal *, integer *, doublereal *,
@@ -733,12 +733,12 @@ f"> */
     extern /* Subroutine */ int xerbla_(char *, integer *, ftnlen);
     doublereal bignum;
     integer indtau;
-    extern /* Subroutine */ int dsterf_(integer *, doublereal *, doublereal *,
+    extern /* Subroutine */ void dsterf_(integer *, doublereal *, doublereal *,
 	     integer *);
     extern doublereal dlansy_(char *, char *, integer *, doublereal *, 
 	    integer *, doublereal *);
     integer indwrk, liwmin;
-    extern /* Subroutine */ int dormtr_(char *, char *, char *, integer *, 
+    extern /* Subroutine */ void dormtr_(char *, char *, char *, integer *, 
 	    integer *, doublereal *, integer *, doublereal *, doublereal *, 
 	    integer *, doublereal *, integer *, integer *), dsytrd_(char *, integer *, doublereal *, integer *, 
 	    doublereal *, doublereal *, doublereal *, doublereal *, integer *,
@@ -820,15 +820,15 @@ f"> */
     if (*info != 0) {
 	i__1 = -(*info);
 	xerbla_("DSYEVD", &i__1, (ftnlen)6);
-	return 0;
+	return;
     } else if (lquery) {
-	return 0;
+	return;
     }
 
 /*     Quick return if possible */
 
     if (*n == 0) {
-	return 0;
+	return;
     }
 
     if (*n == 1) {
@@ -836,7 +836,7 @@ f"> */
 	if (wantz) {
 	    a[a_dim1 + 1] = 1.;
 	}
-	return 0;
+	return;
     }
 
 /*     Get machine constants. */
@@ -901,7 +901,7 @@ f"> */
     work[1] = (doublereal) lopt;
     iwork[1] = liopt;
 
-    return 0;
+    return;
 
 /*     End of DSYEVD */
 
